==> qcpufreq_0.2-2.tar.gz: qcpufreq-0.2/src/de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE" sourcelanguage="en_US">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <location filename="mainwindow.cpp" line="218"/>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="34"/>
        <source>Minimum CPU speed:</source>
        <translation>Min. CPU Frequenz:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="41"/>
        <location filename="mainwindow.ui" line="55"/>
        <location filename="mainwindow.ui" line="69"/>
        <location filename="mainwindow.ui" line="83"/>
        <location filename="mainwindow.cpp" line="107"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="48"/>
        <source>Maximum CPU speed:</source>
        <translation>Max. CPU Frequenz:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="62"/>
        <source>Current scaling governor:</source>
        <translation>Aktueller Skalierer:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="76"/>
        <source>Current CPU temperature:</source>
        <translation>Aktuelle CPU Temperatur:</translation>
    </message>
    <message utf8="true">
        <location filename="mainwindow.ui" line="96"/>
        <source>SmartReflex™:</source>
        <translation>SmartReflex™:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="109"/>
        <location filename="mainwindow.cpp" line="260"/>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="306"/>
        <source>Set maximum CPU frequency:</source>
        <translation>Maximale CPU Frequenz einstellen:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="334"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="342"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="218"/>
        <source>Could not get information from /sys!</source>
        <translation>Konnte Informationen aus /sys nicht lesen!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="257"/>
        <source>Enabled</source>
        <translation>Aktiviert</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="325"/>
        <source>SmartReflex support is known to be unstable on some devices and may cause random reboots.</source>
        <translation>SmartReflex kann auf einigen Geräten instabil sein und zu zufälligen Neustarts führen.</translation>
    </message>
</context>
</TS>

==> qcpufreq_0.3-2.tar.gz: qcpufreq-0.3/src/de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE" sourcelanguage="en_US">
<context>
    <name>HelpWindow</name>
    <message>
        <location filename="helpwindow.ui" line="14"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="helpwindow.cpp" line="56"/>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <location filename="helpwindow.cpp" line="56"/>
        <source>Cannot open help file!</source>
        <translation>Kann die Hilfe-Datei nicht öffnen!</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <location filename="mainwindow.cpp" line="142"/>
        <location filename="mainwindow.cpp" line="271"/>
        <source>QCPUFreq</source>
        <translation>QCPUFreq</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="34"/>
        <source>Minimum CPU speed:</source>
        <translation>Min. CPU Frequenz:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="41"/>
        <location filename="mainwindow.ui" line="55"/>
        <location filename="mainwindow.ui" line="69"/>
        <location filename="mainwindow.ui" line="83"/>
        <location filename="mainwindow.cpp" line="157"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="48"/>
        <source>Maximum CPU speed:</source>
        <translation>Max. CPU Frequenz:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="62"/>
        <source>Current scaling governor:</source>
        <translation>Aktueller Skalierer:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="76"/>
        <source>Current CPU temperature:</source>
        <translation>Aktuelle CPU Temperatur:</translation>
    </message>
    <message utf8="true">
        <location filename="mainwindow.ui" line="96"/>
        <source>SmartReflex™:</source>
        <translation>SmartReflex™:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="109"/>
        <source>Enable</source>
        <oldsource>Disabled</oldsource>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="306"/>
        <source>Set maximum CPU frequency:</source>
        <translation>Maximale CPU Frequenz einstellen:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="334"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="343"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="142"/>
        <source>There seems to be a problem with your sudo setup!</source>
        <translation>Es liegt offenbar ein Problem bei der sudo Einrichtung vor!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="271"/>
        <source>Could not get information from /sys!</source>
        <translation>Konnte Informationen aus /sys nicht lesen!</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation type="obsolete">Aktiviert</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="374"/>
        <source>SmartReflex support is known to be unstable on some devices and may cause random reboots.</source>
        <translation>SmartReflex kann auf einigen Geräten instabil sein und zu zufälligen Neustarts führen.</translation>
    </message>
</context>
</TS>
